]> sigrok.org Git - libsigrok.git/commitdiff
Rename sr_dev_has_hwcap() to sr_dev_has_option().
authorBert Vermeulen <redacted>
Fri, 25 Jan 2013 15:20:40 +0000 (16:20 +0100)
committerBert Vermeulen <redacted>
Fri, 25 Jan 2013 15:20:40 +0000 (16:20 +0100)
device.c
output/chronovu_la8.c
output/csv.c
output/gnuplot.c
output/ols.c
output/text/text.c
output/vcd.c
proto.h
session_file.c

index 75c202898bd3a464f2f1f7aacb7f86e418b93506..b51af2ba5127dda17a5325b1ae5962427471696b 100644 (file)
diff --git a/proto.h b/proto.h
index fef52f8e48228068521c87fd8fe29844ff5fc938..2110368d938cc3812868b060c427201c25ff6219 100644 (file)
--- a/proto.h
+++ b/proto.h
@@ -51,7 +51,7 @@ SR_API int sr_dev_probe_enable(const struct sr_dev_inst *sdi, int probenum,
                gboolean state);
 SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
                const char *trigger);
-SR_API gboolean sr_dev_has_hwcap(const struct sr_dev_inst *sdi, int hwcap);
+SR_API gboolean sr_dev_has_option(const struct sr_dev_inst *sdi, int key);
 SR_API int sr_config_set(const struct sr_dev_inst *sdi, int hwcap,
                const void *value);
 SR_API GSList *sr_dev_inst_list(const struct sr_dev_driver *driver);
index 0a5979e4e1cc3ebe645ad7b5df2dec85f09dab65..1e76028d1e01cd8ff3cbc68e3a2673de1e47df45 100644 (file)
@@ -253,7 +253,7 @@ SR_API int sr_session_save(const char *filename, const struct sr_dev_inst *sdi,
        fprintf(meta, "capturefile = logic-1\n");
        fprintf(meta, "unitsize = %d\n", unitsize);
        fprintf(meta, "total probes = %d\n", g_slist_length(sdi->probes));
-       if (sr_dev_has_hwcap(sdi, SR_CONF_SAMPLERATE)) {
+       if (sr_dev_has_option(sdi, SR_CONF_SAMPLERATE)) {
                if (sr_config_get(sdi->driver, SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, sdi) == SR_OK) {
                        s = sr_samplerate_string(*samplerate);
--- a/device.c
+++ b/device.c
@@ -183,27 +183,27 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *            If the device's 'driver' field is NULL (virtual device), this
  *            function will always return FALSE (virtual devices don't have
  *            a hardware capabilities list).
* @param hwcap The capability that should be checked (whether it's supported
*              by the specified device).
  *
* @return TRUE if the device has the specified capability, FALSE otherwise.
*         FALSE is also returned upon invalid input parameters or other
  *         error conditions.
  */
-SR_API gboolean sr_dev_has_hwcap(const struct sr_dev_inst *sdi, int hwcap)
+SR_API gboolean sr_dev_has_option(const struct sr_dev_inst *sdi, int key)
 {
-       const int *hwcaps;
+       const int *devopts;
        int i;
 
        if (!sdi || !sdi->driver)
                return FALSE;
 
        if (sdi->driver->config_list(SR_CONF_DEVICE_OPTIONS,
-                       (const void **)&hwcaps, NULL) != SR_OK)
+                       (const void **)&devopts, NULL) != SR_OK)
                return FALSE;
 
-       for (i = 0; hwcaps[i]; i++) {
-               if (hwcaps[i] == hwcap)
+       for (i = 0; devopts[i]; i++) {
+               if (devopts[i] == key)
                        return TRUE;
        }
 
index 6074f053e81dd245f624f334b514324216023d2a..f5da904a230f18a6819542f2419fc1391c7b8338 100644 (file)
@@ -128,7 +128,7 @@ static int init(struct sr_output *o)
        ctx->probelist[ctx->num_enabled_probes] = 0;
        ctx->unitsize = (ctx->num_enabled_probes + 7) / 8;
 
-       if (sr_dev_has_hwcap(o->sdi, SR_CONF_SAMPLERATE)) {
+       if (sr_dev_has_option(o->sdi, SR_CONF_SAMPLERATE)) {
                o->sdi->driver->config_get(SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, o->sdi);
                ctx->samplerate = *samplerate;
index 10798a7362ce70ce1a2436f00ec9b4c2d548a187..e2901efbc8f5205fcff1a5ef2299e3ef47a6a991 100644 (file)
@@ -99,7 +99,7 @@ static int init(struct sr_output *o)
 
        num_probes = g_slist_length(o->sdi->probes);
 
-       if (sr_dev_has_hwcap(o->sdi, SR_CONF_SAMPLERATE)) {
+       if (sr_dev_has_option(o->sdi, SR_CONF_SAMPLERATE)) {
                o->sdi->driver->config_get(SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, o->sdi);
                ctx->samplerate = *samplerate;
index f70625a9fd42cdf47b6bd57f1013df0eb53ffce0..965138984a594c7981a4fa8eb2cae660b6eda5cd 100644 (file)
@@ -109,7 +109,7 @@ static int init(struct sr_output *o)
 
        num_probes = g_slist_length(o->sdi->probes);
        comment[0] = '\0';
-       if (sr_dev_has_hwcap(o->sdi, SR_CONF_SAMPLERATE)) {
+       if (sr_dev_has_option(o->sdi, SR_CONF_SAMPLERATE)) {
                o->sdi->driver->config_get(SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, o->sdi);
                if (!(frequency_s = sr_samplerate_string(*samplerate))) {
index 40e48f915e4a92008cb04ac2b76c64754bc01216..c43323a4cede8889e17f88d92cab280941f2285c 100644 (file)
@@ -69,7 +69,7 @@ static int init(struct sr_output *o)
        }
        ctx->unitsize = (num_enabled_probes + 7) / 8;
 
-       if (o->sdi->driver && sr_dev_has_hwcap(o->sdi, SR_CONF_SAMPLERATE))
+       if (o->sdi->driver && sr_dev_has_option(o->sdi, SR_CONF_SAMPLERATE))
                o->sdi->driver->config_get(SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, o->sdi);
        else {
index 8bbe3b51d3b2fed7e32bc701613e83adb89fefdf..3ca9f4f505c98b44374c87410310967f9a5ae314 100644 (file)
@@ -123,7 +123,7 @@ SR_PRIV int init(struct sr_output *o, int default_spl, enum outputmode mode)
 
        snprintf(ctx->header, 511, "%s\n", PACKAGE_STRING);
        num_probes = g_slist_length(o->sdi->probes);
-       if (o->sdi->driver || sr_dev_has_hwcap(o->sdi, SR_CONF_SAMPLERATE)) {
+       if (o->sdi->driver || sr_dev_has_option(o->sdi, SR_CONF_SAMPLERATE)) {
                ret = o->sdi->driver->config_get(SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, o->sdi);
                if (ret != SR_OK)
index 39759d648f82be07de4c20ad167dd611ef60a5c8..b8caeddee5a9cbca4b6ec5382b3eb79221345e60 100644 (file)
@@ -94,7 +94,7 @@ static int init(struct sr_output *o)
        g_string_append_printf(ctx->header, "$version %s %s $end\n",
                        PACKAGE, PACKAGE_VERSION);
 
-       if (o->sdi->driver && sr_dev_has_hwcap(o->sdi, SR_CONF_SAMPLERATE)) {
+       if (o->sdi->driver && sr_dev_has_option(o->sdi, SR_CONF_SAMPLERATE)) {
                o->sdi->driver->config_get(SR_CONF_SAMPLERATE,
                                (const void **)&samplerate, o->sdi);
                ctx->samplerate = *samplerate;
@@ -183,27 +183,27 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *            function will always return FALSE (virtual devices don't have
  *            a hardware capabilities list).
- * @param hwcap The capability that should be checked (whether it's supported
- *              by the specified device).
+ * @param option The option that should be checked for support on the
+ *            specified device.
  *
@@ -183,27 +183,27 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *
- * @return TRUE if the device has the specified capability, FALSE otherwise.
- *         FALSE is also returned upon invalid input parameters or other
+ * @return TRUE if the device has the specified option, FALSE otherwise.
+ *         FALSE is also returned on invalid input parameters or other
  *         error conditions.
  */